@@ -6,9 +6,9 @@ use warnings;
 use Log::ger;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-11-04'; # DATE
+our $DATE = '2023-01-19'; # DATE
 our $DIST = 'App-orgadb'; # DIST
-our $VERSION = '0.015'; # VERSION
+our $VERSION = '0.016'; # VERSION
 
 sub _heading_from_line {
     my $heading = shift;
@@ -405,15 +405,12 @@ _
         'x.name.singular' => 'field_value_formatter',
         summary => 'Add one or more formatters to display field value',
         #schema => ['array*', of=>'perl::perl_sah_filter::modname_with_optional_args*'], ## doesn't work yet with Perinci::Sub::GetArgs::Argv
-        schema => ['array*', of=>'str*'],
-        element_completion => sub {
-            require Complete::Module;
-            my %args = @_;
-            Complete::Module::complete_module(
-                word => $args{word},
-                ns_prefix => 'Data::Sah::Filter::perl',
-            );
-        },
+        schema => ['array*', of=>[
+            'str*', {
+                prefilters=>['Perl::normalize_perl_modname'],
+                'x.completion' => ['perl_perl_sah_filter_modname_with_optional_args'],
+            }],
+               ],
         cmdline_aliases => {
             fvfmt=>{},
             f=>{},
@@ -499,7 +496,7 @@ App::orgadb::Common
 
 =head1 VERSION
 
-This document describes version 0.015 of App::orgadb::Common (from Perl distribution App-orgadb), released on 2022-11-04.
+This document describes version 0.016 of App::orgadb::Common (from Perl distribution App-orgadb), released on 2023-01-19.
 
 =head1 HOMEPAGE
 
@@ -533,7 +530,7 @@ that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2022 by perlancar <perlancar@cpan.org>.
+This software is copyright (c) 2023, 2022 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
